@@ -1,25 +1,28 @@
 #' Identify the OAI-PMH service for each data provider.
 #'
 #' @export
-#' @param url OAI-PMH base url
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
+#' @template url_ddd
 #' @examples \dontrun{
-#' # default, datacite
-#' id()
+#' # datacite
+#' id("http://oai.datacite.org/oai")
+#'
 #' # arxiv
 #' id("http://export.arxiv.org/oai2")
 #'
+#' # GBIF - http://www.gbif.org/
+#' id("http://api.gbif.org/v1/oai-pmh/registry")
+#'
 #' # curl options
 #' library("httr")
-#' id(config = verbose())
+#' id("http://export.arxiv.org/oai2", config = verbose())
 #' }
 id <- function(url, ...) {
   check_url(url)
-  rbind_fill(lapply(url, id_, ...))
+  rbind.fill(lapply(url, id_, ...))
 }
 
 id_ <- function(x, ...) {
   res <- GET(x, query = list(verb = "Identify"), ...)
-  tt <- content(res, as = "text")
+  tt <- content(res, as = "text", encoding = "UTF-8")
   get_headers(xml_children(xml2::read_xml(tt))[[3]])
 }
