@@ -1,9 +1,8 @@
 #' List available metadata formats from various providers.
 #'
 #' @export
-#' @param url OAI-PMH base url
+#' @template url_ddd
 #' @param id The OAI-PMH identifier for the record. Optional.
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
 #' @examples \dontrun{
 #' list_metadataformats()
 #'
@@ -30,7 +29,7 @@ one_mf <- function(identifier, url, ...) {
   args <- sc(list(verb = 'ListMetadataFormats', identifier = identifier))
   res <- GET(url, query = args, ...)
   stop_for_status(res)
-  out <- content(res, "text")
+  out <- content(res, "text", encoding = "UTF-8")
   xml <- xml2::read_xml(out)
-  rbind_fill(lapply(xml_children(xml_children(xml)[[3]]), get_headers))
+  rbind.fill(lapply(xml_children(xml_children(xml)[[3]]), get_headers))
 }
